==> jc-1.4.0.tar.gz: java/nio/charset/spi/CharsetProvider.h <==
// public abstract class java.nio.charset.spi.CharsetProvider

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f5e8d54b80f50935 java_nio_charset_spi_CharsetProvider

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_charset_spi_CharsetProvider_H_
#define _JC_java_nio_charset_spi_CharsetProvider_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_nio_charset_Charset$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_nio_charset_spi_CharsetProvider$sub_refs	_jc_java_nio_charset_spi_CharsetProvider$sub_refs;
typedef struct _jc_java_nio_charset_spi_CharsetProvider$sub_nonrefs	_jc_java_nio_charset_spi_CharsetProvider$sub_nonrefs;
typedef struct _jc_java_nio_charset_spi_CharsetProvider$refs	_jc_java_nio_charset_spi_CharsetProvider$refs;
typedef struct _jc_java_nio_charset_spi_CharsetProvider$nonrefs	_jc_java_nio_charset_spi_CharsetProvider$nonrefs;
typedef struct _jc_java_nio_charset_spi_CharsetProvider$object	_jc_java_nio_charset_spi_CharsetProvider$object;

typedef const struct _jc_java_nio_charset_spi_CharsetProvider$vmethods	_jc_java_nio_charset_spi_CharsetProvider$vmethods;
typedef const struct _jc_java_nio_charset_spi_CharsetProvider$vtable	_jc_java_nio_charset_spi_CharsetProvider$vtable;
typedef const struct _jc_java_nio_charset_spi_CharsetProvider$vtype	_jc_java_nio_charset_spi_CharsetProvider$vtype;

// Constructors
extern void _jc_java_nio_charset_spi_CharsetProvider$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_charset_spi_CharsetProvider$object *);

// Virtual methods
extern struct _jc_java_nio_charset_Charset$object *_jc_java_nio_charset_spi_CharsetProvider$method$charsetForName$cb2dd1cda930620d(_jc_env *, struct _jc_java_nio_charset_spi_CharsetProvider$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_java_nio_charset_spi_CharsetProvider$method$charsets$45ae22f55cf2d149(_jc_env *, struct _jc_java_nio_charset_spi_CharsetProvider$object *);

// Virtual method descriptors
extern _jc_method _jc_java_nio_charset_spi_CharsetProvider$method_info$charsetForName$cb2dd1cda930620d;
extern _jc_method _jc_java_nio_charset_spi_CharsetProvider$method_info$charsets$45ae22f55cf2d149;

// Virtual methods structure
struct _jc_java_nio_charset_spi_CharsetProvider$vmethods {
	struct _jc_java_nio_charset_Charset$object	*(*charsetForName$cb2dd1cda930620d)(_jc_env *, struct _jc_java_nio_charset_spi_CharsetProvider$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*charsets$45ae22f55cf2d149)(_jc_env *, struct _jc_java_nio_charset_spi_CharsetProvider$object *);
};

// Vtable
struct _jc_java_nio_charset_spi_CharsetProvider$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_spi_CharsetProvider$vmethods	java_nio_charset_spi_CharsetProvider;
};

// Vtype
struct _jc_java_nio_charset_spi_CharsetProvider$vtype {
	_jc_type			type;
	_jc_java_nio_charset_spi_CharsetProvider$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_spi_CharsetProvider$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_charset_spi_CharsetProvider$refs {
    _jc_java_nio_charset_spi_CharsetProvider$sub_refs	java_nio_charset_spi_CharsetProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_spi_CharsetProvider$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_spi_CharsetProvider$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_spi_CharsetProvider$sub_nonrefs	java_nio_charset_spi_CharsetProvider;
};

// Object instance structure
struct _jc_java_nio_charset_spi_CharsetProvider$object {
	_jc_java_nio_charset_spi_CharsetProvider$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_spi_CharsetProvider$vtype	*vtype;
	_jc_java_nio_charset_spi_CharsetProvider$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_spi_CharsetProvider$vtype _jc_java_nio_charset_spi_CharsetProvider$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_spi_CharsetProvider, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_spi_CharsetProvider$class_object;

#endif	/* _JC_java_nio_charset_spi_CharsetProvider_H_ */

==> jc-1.4.6.tar.gz: java/nio/charset/spi/CharsetProvider.h <==
// public abstract class java.nio.charset.spi.CharsetProvider

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f5e8d54b80f50935 java_nio_charset_spi_CharsetProvider

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_charset_spi_CharsetProvider_H_
#define _JC_java_nio_charset_spi_CharsetProvider_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_nio_charset_Charset$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_nio_charset_spi_CharsetProvider$sub_refs	_jc_java_nio_charset_spi_CharsetProvider$sub_refs;
typedef struct _jc_java_nio_charset_spi_CharsetProvider$sub_nonrefs	_jc_java_nio_charset_spi_CharsetProvider$sub_nonrefs;
typedef struct _jc_java_nio_charset_spi_CharsetProvider$refs	_jc_java_nio_charset_spi_CharsetProvider$refs;
typedef struct _jc_java_nio_charset_spi_CharsetProvider$nonrefs	_jc_java_nio_charset_spi_CharsetProvider$nonrefs;
typedef struct _jc_java_nio_charset_spi_CharsetProvider$object	_jc_java_nio_charset_spi_CharsetProvider$object;

typedef const struct _jc_java_nio_charset_spi_CharsetProvider$vmethods	_jc_java_nio_charset_spi_CharsetProvider$vmethods;
typedef const struct _jc_java_nio_charset_spi_CharsetProvider$vtable	_jc_java_nio_charset_spi_CharsetProvider$vtable;
typedef const struct _jc_java_nio_charset_spi_CharsetProvider$vtype	_jc_java_nio_charset_spi_CharsetProvider$vtype;

// Constructors
extern void _jc_java_nio_charset_spi_CharsetProvider$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_charset_spi_CharsetProvider$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_nio_charset_Charset$object *_jc_java_nio_charset_spi_CharsetProvider$method$charsetForName$cb2dd1cda930620d(_jc_env *, struct _jc_java_nio_charset_spi_CharsetProvider$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_nio_charset_spi_CharsetProvider$method$charsets$45ae22f55cf2d149(_jc_env *, struct _jc_java_nio_charset_spi_CharsetProvider$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_charset_spi_CharsetProvider$method_info$charsetForName$cb2dd1cda930620d;
extern _jc_method _jc_java_nio_charset_spi_CharsetProvider$method_info$charsets$45ae22f55cf2d149;

// Virtual methods structure
struct _jc_java_nio_charset_spi_CharsetProvider$vmethods {
	struct _jc_java_nio_charset_Charset$object	*(*charsetForName$cb2dd1cda930620d)(_jc_env *, struct _jc_java_nio_charset_spi_CharsetProvider$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*charsets$45ae22f55cf2d149)(_jc_env *, struct _jc_java_nio_charset_spi_CharsetProvider$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_charset_spi_CharsetProvider$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_spi_CharsetProvider$vmethods	java_nio_charset_spi_CharsetProvider;
};

// Vtype
struct _jc_java_nio_charset_spi_CharsetProvider$vtype {
	_jc_type			type;
	_jc_java_nio_charset_spi_CharsetProvider$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_spi_CharsetProvider$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_charset_spi_CharsetProvider$refs {
    _jc_java_nio_charset_spi_CharsetProvider$sub_refs	java_nio_charset_spi_CharsetProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_spi_CharsetProvider$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_spi_CharsetProvider$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_spi_CharsetProvider$sub_nonrefs	java_nio_charset_spi_CharsetProvider;
};

// Object instance structure
struct _jc_java_nio_charset_spi_CharsetProvider$object {
	_jc_java_nio_charset_spi_CharsetProvider$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_spi_CharsetProvider$vtype	*vtype;
	_jc_java_nio_charset_spi_CharsetProvider$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_spi_CharsetProvider$vtype _jc_java_nio_charset_spi_CharsetProvider$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_spi_CharsetProvider, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_spi_CharsetProvider$class_object;

#endif	/* _JC_java_nio_charset_spi_CharsetProvider_H_ */
